
# Slot: version of




URI: [biolink:version_of](https://w3id.org/biolink/vocab/version_of)


## Domain and Range

[DatasetVersion](DatasetVersion.md) &#8594;  <sub>0..1</sub> [DatasetSummary](DatasetSummary.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | dct:isVersionOf |

